@@ -1,6 +1,6 @@
 package Test::Mojo::Role::TestDeep;
 # ABSTRACT: Add Test::Deep methods to Test::Mojo::WithRoles
-$Test::Mojo::Role::TestDeep::VERSION = '0.002';
+$Test::Mojo::Role::TestDeep::VERSION = '0.003';
 
 use strict;
 use warnings;
@@ -41,7 +41,7 @@ Test::Mojo::Role::TestDeep - Add Test::Deep methods to Test::Mojo::WithRoles
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -69,8 +69,8 @@ allows for extremely-customizable testing of data structures.
 
 Test that the current response (parsed as a JSON object) matches the given
 tests. C<$expect> is a data structure containing L<Test::Deep
-comparisons|SPECIAL COMPARISONS PROVIDED> to run. C<$desc> is a description of
-the test.
+comparisons|Test::Deep/SPECIAL COMPARISONS PROVIDED> to run. C<$desc> is a
+description of the test.
 
 If given, C<$ptr> is a JSON pointer string to pick out a single part of the
 data structure. This is more convenient than using Test::Deep's comparison
